@@ -3,5 +3,5 @@
 
 from .abc_evaluator import InterpreterEvaluator
 from .deletion_insertion import DeletionInsertion
-from .perturbation import Perturbation
-from .localization import PointGame, PointGameSegmentation
+from .perturbation import Perturbation, PerturbationNLP
+from .infidelity import Infidelity, InfidelityNLP
