@@ -1,7 +1,7 @@
 import numpy as np
 import cv2
 from .abc_evaluator import InterpreterEvaluator
-from interpretdl.data_processor.readers import images_transform_pipeline, preprocess_image
+from ..data_processor.readers import images_transform_pipeline, preprocess_image
 
 
 class Perturbation(InterpreterEvaluator):
@@ -30,17 +30,17 @@ class Perturbation(InterpreterEvaluator):
     """
 
     def __init__(self,
-                 paddle_model: callable,
-                 device: str,
+                 model: callable,
+                 device: str = 'gpu:0',
                  compute_MoRF: bool = True,
                  compute_LeRF: bool = True,
                  **kwargs):
         """_summary_
 
         Args:
-            paddle_model (callable): A model with :py:func:`forward` and possibly :py:func:`backward` functions. This 
+            model (callable): A model with :py:func:`forward` and possibly :py:func:`backward` functions. This 
                 is not always required if the model is not involved. 
-            device (str): The device used for running ``paddle_model``, options: ``"cpu"``, ``"gpu:0"``, ``"gpu:1"`` 
+            device (str): The device used for running ``model``, options: ``"cpu"``, ``"gpu:0"``, ``"gpu:1"`` 
                 etc. Again, this is not always required if the model is not involved.
             compute_MoRF (bool, optional): Whether comptue MoRF score. Defaults to True.
             compute_LeRF (bool, optional): Whether comptue LeRF score. Defaults to True.
@@ -48,7 +48,7 @@ class Perturbation(InterpreterEvaluator):
         Raises:
             ValueError: 'At least one of ``compute_MoRF`` and ``compute_LeRF`` must be True.'
         """
-        super().__init__(paddle_model, device, None, **kwargs)
+        super().__init__(model, device, **kwargs)
 
         if (not compute_MoRF) and (not compute_LeRF):
             raise ValueError('At least one of ``compute_MoRF`` and ``compute_LeRF`` must be True.')
@@ -58,42 +58,6 @@ class Perturbation(InterpreterEvaluator):
 
         self._build_predict_fn()
 
-    def _build_predict_fn(self, rebuild: bool = False):
-        if self.predict_fn is not None:
-            assert callable(self.predict_fn), "predict_fn is predefined before, but is not callable." \
-                "Check it again."
-
-        import paddle
-        if self.predict_fn is None or rebuild:
-            if not paddle.is_compiled_with_cuda() and self.device[:3] == 'gpu':
-                print("Paddle is not installed with GPU support. Change to CPU version now.")
-                self.device = 'cpu'
-
-            # set device. self.device is one of ['cpu', 'gpu:0', 'gpu:1', ...]
-            paddle.set_device(self.device)
-
-            # to get gradients, the ``train`` mode must be set.
-            self.paddle_model.eval()
-
-            def predict_fn(data):
-                """predict_fn for input gradients based interpreters,
-                    for image classification models only.
-
-                Args:
-                    data ([type]): [description]
-
-                Returns:
-                    [type]: [description]
-                """
-                assert len(data.shape) == 4  # [bs, h, w, 3]
-
-                with paddle.no_grad():
-                    logits = self.paddle_model(paddle.to_tensor(data))  # get logits, [bs, num_c]
-                    probas = paddle.nn.functional.softmax(logits, axis=1)  # get probabilities.
-                return probas.numpy()
-
-            self.predict_fn = predict_fn
-
     def evaluate(self,
                  img_path: str,
                  explanation: list or np.ndarray,
@@ -306,3 +270,148 @@ class Perturbation(InterpreterEvaluator):
             results['LeRF_score'] = np.mean(results['LeRF_probas'])
 
         return results
+
+
+class PerturbationNLP(InterpreterEvaluator):
+    """Perturbation based Evaluations for NLP tasks. 
+
+    More details of MoRF and LeRF can be found in the original paper:
+    https://arxiv.org/abs/1509.06321. 
+
+    """
+
+    def __init__(self,
+                 model: callable,
+                 device: str = 'gpu:0',
+                 **kwargs):
+        """_summary_
+
+        Args:
+            model (callable): A model with :py:func:`forward` and possibly :py:func:`backward` functions. This 
+                is not always required if the model is not involved. 
+            device (str): The device used for running ``model``, options: ``"cpu"``, ``"gpu:0"``, ``"gpu:1"`` 
+                etc. Again, this is not always required if the model is not involved.
+            compute_MoRF (bool, optional): Whether comptue MoRF score. Defaults to True.
+            compute_LeRF (bool, optional): Whether comptue LeRF score. Defaults to True.
+
+        Raises:
+            ValueError: 'At least one of ``compute_MoRF`` and ``compute_LeRF`` must be True.'
+        """
+        super().__init__(model, device, None, **kwargs)
+        self._build_predict_fn()
+
+    def evaluate(self,
+                 raw_text: str,
+                 explanation: list or np.ndarray,
+                 tokenizer: callable,
+                 compute_MoRF: bool = True,
+                 compute_LeRF: bool = True,
+                 batch_size=None,
+                 max_seq_len=128,
+                 percentile=False) -> dict:
+
+        if (not compute_MoRF) and (not compute_LeRF):
+            raise ValueError('At least one of ``compute_MoRF`` and ``compute_LeRF`` must be True.')
+        self.compute_MoRF = compute_MoRF
+        self.compute_LeRF = compute_LeRF
+
+        results = {}
+        if compute_MoRF:
+            results['MoRF_score'] = 0.0
+            results['MoRF_probas'] = None
+        if compute_LeRF:
+            results['LeRF_score'] = 0.0
+            results['LeRF_probas'] = None
+
+        results = self.generate_samples(
+            raw_text, explanation, tokenizer, max_seq_len, percentile, results)
+
+        results = self.compute_probas(results, batch_size)
+
+        return results
+
+    def generate_samples(self, raw_text, explanation, tokenizer, max_seq_len, percentile, results=None):
+        if results is None:
+            results = {}
+        
+        # tokenizer text to ids
+        encoded_inputs = tokenizer(raw_text, max_seq_len=max_seq_len)
+
+        explanation = np.squeeze(explanation)
+        assert explanation.shape[0] == len(encoded_inputs['input_ids'])
+
+        text_explanation = explanation[1:-1]  # without special tokens
+        # perturb on text or directly on ids. use tokenizer.pad_token_id
+        if percentile:
+            # perturb tokens according to the percentiles.
+            qs = [i for i in range(101)]
+            tiles = np.percentile(text_explanation, qs)
+        else:
+            # (default setting) perturb tokens one by one. 
+            tiles = np.sort(text_explanation)
+
+        # this is for [cls] token tasks.
+        cls_id = encoded_inputs['input_ids'][0]
+        sep_id = encoded_inputs['input_ids'][-1]
+        pad_id = tokenizer.pad_token_id  # use pad_token to mask original ids.
+
+        if self.compute_MoRF:
+            batched_input_ids = [encoded_inputs['input_ids'].copy()]
+            MoRF_tiles = tiles[:100]
+            for p in MoRF_tiles[::-1]:
+                inputs_copy = encoded_inputs.copy()
+                _tmp_input_ids = np.array(inputs_copy['input_ids'])
+                _tmp_input_ids[explanation >= p] = pad_id
+                _tmp_input_ids[0] = cls_id
+                _tmp_input_ids[-1] = sep_id
+                batched_input_ids.append(_tmp_input_ids)
+            batched_input_ids = np.array(batched_input_ids)
+            results['MoRF_samples'] = (batched_input_ids, )
+                
+        if self.compute_LeRF:
+            batched_input_ids = [encoded_inputs['input_ids'].copy()]
+            LeRF_tiles = tiles[1:]
+            for p in LeRF_tiles:
+                inputs_copy = encoded_inputs.copy()
+                _tmp_input_ids = np.array(inputs_copy['input_ids'])
+                _tmp_input_ids[explanation <= p] = pad_id
+                _tmp_input_ids[0] = cls_id
+                _tmp_input_ids[-1] = sep_id
+                batched_input_ids.append(_tmp_input_ids)
+            batched_input_ids = np.array(batched_input_ids)
+            results['LeRF_samples'] = (batched_input_ids, )
+
+        return results
+
+    def compute_probas(self, results, batch_size, coi=None):
+        if self.compute_MoRF:
+            data = results['MoRF_samples']
+            if batch_size is None:
+                probas = self.predict_fn(data)
+            else:
+                raise NotImplementedError
+
+            # class of interest
+            if coi is None:
+                # probas.shape = [n_samples, n_classes]
+                coi = np.argmax(probas[0], axis=0)
+
+            results['MoRF_probas'] = probas[:, coi]
+            results['MoRF_score'] = np.mean(results['MoRF_probas'])
+
+        if self.compute_LeRF:
+            data = results['LeRF_samples']
+            if batch_size is None:
+                probas = self.predict_fn(data)
+            else:
+                raise NotImplementedError
+
+            # class of interest
+            if coi is None:
+                # probas.shape = [n_samples, n_classes]
+                coi = np.argmax(probas[0], axis=0)
+
+            results['LeRF_probas'] = probas[:, coi]
+            results['LeRF_score'] = np.mean(results['LeRF_probas'])
+
+        return results
