@@ -20,20 +20,22 @@ class NormLIMECVInterpreter(LIMECVInterpreter):
 
     """
 
-    def __init__(self, paddle_model: callable, device: str = 'gpu:0', use_cuda=None):
+    def __init__(self, model: callable, device: str = 'gpu:0'):
         """
 
         Args:
-            paddle_model (callable): A model with :py:func:`forward` and possibly :py:func:`backward` functions.
-            device (str): The device used for running ``paddle_model``, options: ``"cpu"``, ``"gpu:0"``, ``"gpu:1"`` etc.
+            model (callable): A model with :py:func:`forward` and possibly :py:func:`backward` functions.
+            device (str): The device used for running ``model``, options: ``"cpu"``, ``"gpu:0"``, ``"gpu:1"`` etc.
         """
 
-        LIMECVInterpreter.__init__(self, paddle_model, use_cuda=use_cuda, device=device)
+        LIMECVInterpreter.__init__(self, model, device)
         self.lime_interpret = super().interpret
 
     def _get_lime_weights(self, data, num_samples, batch_size, save=False):
         if data in self.all_lime_weights:
             return
+        
+        self.lime_base.segments = None  # set to None to force recompute the segmentation.
         lime_weights = self.lime_interpret(data, num_samples=num_samples, batch_size=batch_size, visual=False)
 
         sp_seg = self.lime_results['segmentation']
@@ -186,14 +188,14 @@ class NormLIMENLPInterpreter(LIMENLPInterpreter):
 
     """
 
-    def __init__(self, paddle_model: callable, device: str = 'gpu:0', use_cuda=None):
+    def __init__(self, model: callable, device: str = 'gpu:0'):
         """
 
         Args:
-            paddle_model (callable): A model with :py:func:`forward` and possibly :py:func:`backward` functions.
-            device (str): The device used for running ``paddle_model``, options: ``"cpu"``, ``"gpu:0"``, ``"gpu:1"`` etc.
+            model (callable): A model with :py:func:`forward` and possibly :py:func:`backward` functions.
+            device (str): The device used for running ``model``, options: ``"cpu"``, ``"gpu:0"``, ``"gpu:1"`` etc.
         """
-        LIMENLPInterpreter.__init__(self, paddle_model, device, use_cuda)
+        LIMENLPInterpreter.__init__(self, model, device)
         self.lime_interpret = super().interpret
 
     def _get_lime_weights(self, data, preprocess_fn, num_samples, batch_size, unk_id, pad_id, lod_levels, save=False):
@@ -212,11 +214,10 @@ class NormLIMENLPInterpreter(LIMENLPInterpreter):
             return
 
         lime_weights = self.lime_interpret(data,
-                                           preprocess_fn=preprocess_fn,
+                                           text_to_input_fn=preprocess_fn,
                                            unk_id=unk_id,
                                            pad_id=pad_id,
                                            num_samples=num_samples,
-                                           lod_levels=lod_levels,
                                            batch_size=batch_size)
 
         self.all_lime_weights[dict_key] = {
@@ -230,12 +231,12 @@ class NormLIMENLPInterpreter(LIMENLPInterpreter):
         return
 
     def interpret(self,
-                  data: str,
+                  list_of_raw_text,
                   preprocess_fn: callable,
                   num_samples: int,
                   batch_size: int,
-                  unk_id: int,
-                  pad_id: int or None = None,
+                  unk_id: int = 0,
+                  pad_id: int = 0,
                   lod_levels: int or None = None,
                   save_path: str = 'normlime_weights.npy',
                   temp_data_file: str = 'all_lime_weights.npz'):
@@ -245,7 +246,7 @@ class NormLIMENLPInterpreter(LIMENLPInterpreter):
         and ``batch_size`` are LIME arguments, for the generated samples and the batch size of each pass.
 
         Args:
-            data (str): The raw string for analysis.
+            list_of_raw_text (str): The raw string for analysis.
             preprocess_fn (Callable): A user-defined function that input raw string and outputs the a tuple of inputs 
                 to feed into the NLP model.
             num_samples (int, optional): LIME sampling numbers. Larger number of samples usually gives more accurate 
@@ -288,8 +289,8 @@ class NormLIMENLPInterpreter(LIMENLPInterpreter):
                 self.all_lime_weights = dict(np.load(self.filepath_to_save, allow_pickle=True))
 
         # compute lime weights and put in self.all_lime_weights
-        for i in tqdm(range(len(data)), leave=True, position=0):
-            self._get_lime_weights(data[i],
+        for i in tqdm(range(len(list_of_raw_text)), leave=True, position=0):
+            self._get_lime_weights(list_of_raw_text[i],
                                    preprocess_fn=preprocess_fn,
                                    unk_id=unk_id,
                                    pad_id=pad_id,
