@@ -19,15 +19,15 @@ class GradShapCVInterpreter(InputGradientInterpreter):
     http://papers.nips.cc/paper/7062-a-unified-approach-to-interpreting-model-predictions.
     """
 
-    def __init__(self, paddle_model: callable, device: str = 'gpu:0', use_cuda=None):
+    def __init__(self, model: callable, device: str = 'gpu:0'):
         """
         
         Args:
-            paddle_model (callable): A model with :py:func:`forward` and possibly :py:func:`backward` functions.
-            device (str): The device used for running ``paddle_model``, options: ``"cpu"``, ``"gpu:0"``, ``"gpu:1"`` 
+            model (callable): A model with :py:func:`forward` and possibly :py:func:`backward` functions.
+            device (str): The device used for running ``model``, options: ``"cpu"``, ``"gpu:0"``, ``"gpu:1"`` 
                 etc.
         """
-        InputGradientInterpreter.__init__(self, paddle_model, device, use_cuda)
+        InputGradientInterpreter.__init__(self, model, device)
 
     def interpret(self,
                   inputs: str or list(str) or np.ndarray,
@@ -35,6 +35,7 @@ class GradShapCVInterpreter(InputGradientInterpreter):
                   baselines: np.ndarray = None,
                   n_samples: int = 5,
                   noise_amount: float = 0.1,
+                  gradient_of: str = 'probability',
                   resize_to: int = 224,
                   crop_to: int = None,
                   visual: bool = True,
@@ -54,6 +55,8 @@ class GradShapCVInterpreter(InputGradientInterpreter):
             n_samples (int, optional): The number of randomly generated samples. Defaults to ``5``.
             noise_amount (float, optional): Noise level of added noise to each image. The std of Gaussian random noise
                 is ``noise_amount`` * (x :sub:`max` - x :sub:`min`). Default: ``0.1``.
+            gradient_of (str, optional): compute the gradient of ['probability', 'logit' or 'loss']. Default: 
+                ``'probability'``. SmoothGrad uses probability for all tasks by default.
             resize_to (int, optional): Images will be rescaled with the shorter edge being ``resize_to``. Defaults to 
                 ``224``.
             crop_to (int, optional): After resize, images will be center cropped to a square image with the size 
@@ -70,10 +73,13 @@ class GradShapCVInterpreter(InputGradientInterpreter):
         bsz = len(data)
         self.data_type = np.array(data).dtype
 
-        self._build_predict_fn(gradient_of='probability')
+        self._build_predict_fn(gradient_of=gradient_of)
 
+        _, predicted_label, predicted_proba = self.predict_fn(data, labels)
+        self.predicted_label = predicted_label
+        self.predicted_proba = predicted_proba
         if labels is None:
-            _, labels = self.predict_fn(data, labels)
+            labels = predicted_label
 
         def add_noise_to_inputs(data):
             max_axis = tuple(np.arange(1, data.ndim))
@@ -98,7 +104,7 @@ class GradShapCVInterpreter(InputGradientInterpreter):
         input_baseline_points = np.array(
             [d * r + b * (1 - r) for d, r, b in zip(data_with_noise, rand_scales, baselines)])
 
-        gradients, _ = self.predict_fn(input_baseline_points, labels)
+        gradients, _, _ = self.predict_fn(input_baseline_points, labels)
 
         input_baseline_diff = data_with_noise - baselines
         explanations = gradients * input_baseline_diff
@@ -120,6 +126,7 @@ class GradShapCVInterpreter(InputGradientInterpreter):
 
 class GradShapNLPInterpreter(Interpreter):
     """
+    TODO: Inherit from a subabstract interpreter.
     Gradient SHAP Interpreter for NLP tasks.
 
     For input gradient based interpreters, the target issue is generally the vanilla input gradient's noises.
@@ -133,15 +140,15 @@ class GradShapNLPInterpreter(Interpreter):
     http://papers.nips.cc/paper/7062-a-unified-approach-to-interpreting-model-predictions.
     """
 
-    def __init__(self, paddle_model: callable, device: str = 'gpu:0', use_cuda: bool = None) -> None:
+    def __init__(self, model: callable, device: str = 'gpu:0') -> None:
         """
         
         Args:
-            paddle_model (callable): A model with :py:func:`forward` and possibly :py:func:`backward` functions.
-            device (str): The device used for running ``paddle_model``, options: ``"cpu"``, ``"gpu:0"``, ``"gpu:1"`` 
+            model (callable): A model with :py:func:`forward` and possibly :py:func:`backward` functions.
+            device (str): The device used for running ``model``, options: ``"cpu"``, ``"gpu:0"``, ``"gpu:1"`` 
                 etc.
         """
-        Interpreter.__init__(self, paddle_model, device, use_cuda)
+        Interpreter.__init__(self, model, device)
 
     def interpret(self,
                   data: tuple or np.ndarray,
@@ -178,6 +185,9 @@ class GradShapNLPInterpreter(Interpreter):
             bs = data.shape[0]
 
         gradients, labels, data_out, probas = self.predict_fn(data, labels, None)
+        self.predicted_label = labels
+        self.predicted_proba = probas
+
         labels = labels.reshape((bs, ))
         total_gradients = np.zeros_like(gradients)
 
@@ -208,22 +218,7 @@ class GradShapNLPInterpreter(Interpreter):
         import paddle
         if self.predict_fn is None or rebuild:
 
-            if not paddle.is_compiled_with_cuda() and self.device[:3] == 'gpu':
-                print("Paddle is not installed with GPU support. Change to CPU version now.")
-                self.device = 'cpu'
-
-            # set device. self.device is one of ['cpu', 'gpu:0', 'gpu:1', ...]
-            paddle.set_device(self.device)
-
-            # to get gradients, the ``train`` mode must be set.
-            self.paddle_model.train()
-
-            # later version will be simplied.
-            for n, v in self.paddle_model.named_sublayers():
-                # if "batchnorm" in v.__class__.__name__.lower():
-                #     v._use_global_stats = True
-                if "dropout" in v.__class__.__name__.lower():
-                    v.p = 0
+            self._paddle_env_setup()
 
             def predict_fn(data, labels, scale=None, noise_amount=None):
                 if isinstance(data, tuple):
@@ -249,15 +244,15 @@ class GradShapNLPInterpreter(Interpreter):
                     return output
 
                 hooks = []
-                for name, v in self.paddle_model.named_sublayers():
+                for name, v in self.model.named_sublayers():
                     if embedding_name in name:
                         h = v.register_forward_post_hook(hook)
                         hooks.append(h)
 
                 if isinstance(data, tuple):
-                    logits = self.paddle_model(*data)  # get logits, [bs, num_c]
+                    logits = self.model(*data)  # get logits, [bs, num_c]
                 else:
-                    logits = self.paddle_model(data)  # get logits, [bs, num_c]
+                    logits = self.model(data)  # get logits, [bs, num_c]
 
                 for h in hooks:
                     h.remove()
