@@ -3,32 +3,34 @@ import paddle
 
 from .lime import LIMECVInterpreter
 from ._lime_base import compute_segments
-from ._global_prior_base import precompute_global_prior, use_fast_normlime_as_prior
-from ..data_processor.readers import images_transform_pipeline, preprocess_image, load_npy_dict_file
+from ._global_prior_base import precompute_global_prior, cluster_global_weights_to_local_prior
+from ..data_processor.readers import preprocess_image, read_image, restore_image
+from ..data_processor.readers import load_npy_dict_file
 from ..data_processor.visualizer import sp_weights_to_image_explanation, overlay_threshold, save_image, show_vis_explanation
 
 
 class LIMEPriorInterpreter(LIMECVInterpreter):
     """
     LIME Prior Interpreter. This is an Interpreter in progress.
+
+    Depreciated. Refer to GLIMECVInterpreter.
     """
 
     def __init__(self,
-                 paddle_model: callable,
+                 model: callable,
                  prior_method: str = "none",
-                 device: str = 'gpu:0',
-                 use_cuda=None) -> None:
+                 device: str = 'gpu:0') -> None:
         """
 
         Args:
-            paddle_model (callable): A model with :py:func:`forward` and possibly :py:func:`backward` functions.
+            model (callable): A model with :py:func:`forward` and possibly :py:func:`backward` functions.
             prior_method: Prior method. Can be chosen from ``{"none", "ridge"}``. Defaults to ``"none"``, which is 
                 equivalent to LIME. If ``none``, :py:func:`interpret()` will use zeros as prior; Otherwise, the loaded
                 prior will be used.
-            device (str): The device used for running ``paddle_model``, options: ``"cpu"``, ``"gpu:0"``, ``"gpu:1"`` 
+            device (str): The device used for running ``model``, options: ``"cpu"``, ``"gpu:0"``, ``"gpu:1"`` 
                 etc.
         """
-        LIMECVInterpreter.__init__(self, paddle_model, device, use_cuda)
+        LIMECVInterpreter.__init__(self, model, device)
         self.prior_method = prior_method
         self.global_weights = None
 
@@ -61,7 +63,7 @@ class LIMEPriorInterpreter(LIMECVInterpreter):
         def predict_fn_for_lime(_imgs):
             _data = preprocess_image(_imgs)  # transpose to [N, 3, H, W], scaled to [0.0, 1.0]
 
-            output, _ = self.predict_fn(_data, None)
+            output, _, _ = self.predict_fn(_data, None)
             return output
 
         self.predict_fn_for_lime = predict_fn_for_lime
@@ -76,13 +78,13 @@ class LIMEPriorInterpreter(LIMECVInterpreter):
                 np.save(weights_file_path, self.global_weights)
 
     def interpret(self,
-                  inputs: str,
+                  data: str,
                   interpret_class: int or None = None,
                   prior_reg_force: float = 1.0,
                   num_samples: int = 1000,
                   batch_size: int = 50,
-                  resize_to: int = 256,
-                  crop_to: int = 224,
+                  resize_to: int = 224,
+                  crop_to: int = None,
                   visual: bool = True,
                   save_path: str = None):
         """
@@ -90,7 +92,7 @@ class LIMEPriorInterpreter(LIMECVInterpreter):
         :py:func:`interpret()`.
 
         Args:
-            inputs (str): The input file path.
+            data (str): The input file path.
             interpret_class (int, optional): The index of class to interpret. If None, the most likely label will be 
                 used. Default: ``None``.
             prior_reg_force (float, optional): The regularization force to apply. Default: ``1.0``.
@@ -111,13 +113,24 @@ class LIMEPriorInterpreter(LIMECVInterpreter):
         """
         if self.global_weights is None and self.prior_method != "none":
             raise ValueError("The interpreter is not prepared. Call prepare() before interpretation.")
-        imgs, data = images_transform_pipeline(inputs, resize_to, crop_to)
+
+        # preprocess_input
+        if isinstance(data, str):
+            img = read_image(data, resize_to, crop_to)
+        else:
+            if len(data.shape) == 3:
+                data = np.expand_dims(data, axis=0)
+            if np.issubdtype(data.dtype, np.integer):
+                img = data
+            else:
+                # for later visualization
+                img = restore_image(data.copy())
+        data = preprocess_image(img)
 
         self._build_predict_fn(output='probability')
 
-        probability, _ = self.predict_fn(data, None)
-        # only one example here
-        probability = probability[0]
+        probability, _, _ = self.predict_fn(data, None)
+        probability = probability[0]  # only one example here
 
         if interpret_class is None:
             # only interpret top 1 if not provided.
@@ -138,14 +151,17 @@ class LIMEPriorInterpreter(LIMECVInterpreter):
         #     return output
 
         # self.predict_fn_for_lime = predict_fn_for_lime
+        if self.lime_base.segments is None:
+            self.lime_base.segments = compute_segments(img[0])
+
+        segments = self.lime_base.segments
 
-        segments = compute_segments(imgs[0])
         if self.prior_method == "none":
             prior = np.zeros(len(np.unique(segments)))
         else:
-            prior = use_fast_normlime_as_prior(imgs, segments, interpret_class[0], self.global_weights)
+            prior = cluster_global_weights_to_local_prior(img, segments, interpret_class[0], self.global_weights)
 
-        lime_weights, r2_scores = self.lime_base.interpret_instance(imgs[0],
+        lime_weights, r2_scores = self.lime_base.interpret_instance(img[0],
                                                                     self.predict_fn_for_lime,
                                                                     interpret_class,
                                                                     num_samples=num_samples,
@@ -154,16 +170,16 @@ class LIMEPriorInterpreter(LIMECVInterpreter):
                                                                     reg_force=prior_reg_force)
 
         # visualization and save image.
-        explanation_mask = sp_weights_to_image_explanation(imgs[0], lime_weights, interpret_class[0],
+        explanation_mask = sp_weights_to_image_explanation(img[0], lime_weights, interpret_class[0],
                                                            self.lime_base.segments)
-        explanation_vis = overlay_threshold(imgs[0], explanation_mask)
+        explanation_vis = overlay_threshold(img[0], explanation_mask)
         if visual:
             show_vis_explanation(explanation_vis)
         if save_path is not None:
             save_image(save_path, explanation_vis)
 
         self.lime_results['probability'] = probability
-        self.lime_results['input'] = imgs[0]
+        self.lime_results['input'] = img[0]
         self.lime_results['segmentation'] = self.lime_base.segments
         self.lime_results['r2_scores'] = r2_scores
         self.lime_results['lime_weights'] = lime_weights
