@@ -24,16 +24,16 @@ class SmoothGradInterpreterV2(InputGradientInterpreter):
     http://arxiv.org/abs/1706.03825.
     """
 
-    def __init__(self, paddle_model: callable, device: str = 'gpu:0', use_cuda=None):
+    def __init__(self, model: callable, device: str = 'gpu:0'):
         """
 
         Args:
-            paddle_model (callable): A model with :py:func:`forward` and possibly :py:func:`backward` functions.
-            device (str): The device used for running ``paddle_model``, options: ``"cpu"``, ``"gpu:0"``, ``"gpu:1"`` 
+            model (callable): A model with :py:func:`forward` and possibly :py:func:`backward` functions.
+            device (str): The device used for running ``model``, options: ``"cpu"``, ``"gpu:0"``, ``"gpu:1"`` 
                 etc.
         """
 
-        InputGradientInterpreter.__init__(self, paddle_model, device, use_cuda)
+        InputGradientInterpreter.__init__(self, model, device)
 
     def interpret(self,
                   inputs: str or list(str) or np.ndarray,
@@ -41,6 +41,7 @@ class SmoothGradInterpreterV2(InputGradientInterpreter):
                   noise_amount: int = 0.1,
                   n_samples: int = 50,
                   split: int = 2,
+                  gradient_of: str = 'probability',
                   resize_to: int = 224,
                   crop_to: int = None,
                   visual: bool = True,
@@ -59,6 +60,8 @@ class SmoothGradInterpreterV2(InputGradientInterpreter):
                 is ``noise_amount`` * (x :sub:`max` - x :sub:`min`). Default: ``0.1``.
             n_samples (int, optional): The number of new images generated by adding noise. Default: ``50``.
             split (int, optional): The number of splits. Default: ``2``.
+            gradient_of (str, optional): compute the gradient of ['probability', 'logit' or 'loss']. Default: 
+                ``'probability'``. SmoothGrad uses probability for all tasks by default.
             resize_to (int, optional): Images will be rescaled with the shorter edge being ``resize_to``. Defaults to 
                 ``224``.
             crop_to (int, optional): After resize, images will be center cropped to a square image with the size 
@@ -76,12 +79,14 @@ class SmoothGradInterpreterV2(InputGradientInterpreter):
 
         assert len(data) == 1, "interpret each sample individually, it is optimized."
 
-        self._build_predict_fn(gradient_of='probability')
+        self._build_predict_fn(gradient_of=gradient_of)
 
         # obtain the labels (and initialization).
+        _, predicted_label, predicted_proba = self.predict_fn(data, labels)
+        self.predicted_label = predicted_label
+        self.predicted_proba = predicted_proba
         if labels is None:
-            _, preds = self.predict_fn(data, None)
-            labels = preds
+            labels = predicted_label
 
         labels = np.array(labels).reshape((1, ))
 
@@ -104,15 +109,15 @@ class SmoothGradInterpreterV2(InputGradientInterpreter):
             chunk = n_samples // split
             gradient_chunks = []
             for i in range(split - 1):
-                gradients_i, _ = self.predict_fn(data_noised[i * chunk:(i + 1) * chunk], np.repeat(labels, chunk))
+                gradients_i, _, _ = self.predict_fn(data_noised[i * chunk:(i + 1) * chunk], np.repeat(labels, chunk))
                 gradient_chunks.append(gradients_i)
-            gradients_s, _ = self.predict_fn(data_noised[chunk * (split - 1):],
+            gradients_s, _, _ = self.predict_fn(data_noised[chunk * (split - 1):],
                                              np.repeat(labels, n_samples - chunk * (split - 1)))
             gradient_chunks.append(gradients_s)
             gradients = np.concatenate(gradient_chunks, axis=0)
         else:
             # one split.
-            gradients, _ = self.predict_fn(data_noised, np.repeat(labels, n_samples))
+            gradients, _, _ = self.predict_fn(data_noised, np.repeat(labels, n_samples))
 
         avg_gradients = np.mean(gradients, axis=0, keepdims=True)
         # visualize and save image.
